@@ -5,14 +5,14 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-# Version: $Id: Base.pm,v 1.1 2001/08/17 07:50:28 parkerpine Exp $
+# Version: $Id: Base.pm,v 1.2 2001/09/02 09:31:54 parkerpine Exp $
 
 package Mail::MboxParser::Base;
 
 require 5.004;
 
 use vars qw($VERSION);
-$VERSION = "0.01";
+$VERSION = "0.02";
 
 sub new(@) {
 	my ($class, @args) = @_;
@@ -26,7 +26,7 @@ Instead, create one of its derived subclasses such as Mail::MboxParser.
 USAGE
 	}
 	my $self = bless {}, $class;
-	$self->init(\@args);
+	$self->init(@args);
 }
 
 sub error() { shift->{LAST_ERR} }
